#!/usr/bin/ksh
#
# Digital Equipment LN40
# Advanced Printing self-extracting installation script.
#
KIT_COPYRIGHT="Copyright (c) 2003 Hewlett-Packard Company"

KIT_APS=APS
KIT_LPD=LPD
KIT_MINVER="V1.0"
KIT_TYPE=$KIT_APS
KIT_PRINTER="Digital Equipment LN40"
KIT_FILES="Digital_LN40_PS.paf"

function setupInstructions {
	print "After the installation script has successfully completed, use the" >&2
	print "/usr/pd/scripts/pd_get_started script or pdprintadmin tool to create" >&2
	print "a new printer and queue." >&2
	print "" >&2
	print "For additional information refer to the Advanced Printing Software" >&2
	print "System Administration and Operation Guide." >&2
}


# Function:
#	askUser Prompt
#
# Description:
#	Prompt for a yes/no response. Default response is no.
#
# Arguments:
#	$1 Prompt Text
#
# Returns:
#	0 User entered yes
#	1 User entered no
#
function askUser {

	print "$1? <Y/N> \c" >&2
	read Response

	case "$Response" in
	[Yy])	return 0
		;;
	[Yy][Ee][Ss])
		return 0
		;;
	*)	return 1
		;;
	esac
}

# Function:
#	wrapMsg Text
#
# Description:
#	Pipe text to fold utility to make sure it will fit
#	within 80 characters.
#
# Arguments:
#	$1 Text, Message Text
#
# Returns:
#	n/a

function wrapMsg {
	print "$1" | fold -s >&2
}

# Function:
#	printLicenseAgreement
#
# Description:
#	Print license agreement
#
# Arguments:
#	None
#
# Returns:
#	Exits when the user does not agree to the terms of the license.

function PrintLicenseAgreement {

    wrapMsg "${KIT_COPYRIGHT}. All rights reserved.\n"

    msg1="                HEWLETT-PACKARD SOFTWARE PRODUCT"
    msg2="                  \"AS IS\" WARRANTY STATEMENT"
    wrapMsg "$msg1\n$msg2\n"

    msg1="DISCLAIMER. TO THE EXTENT ALLOWED BY LOCAL LAW, THIS HP SOFTWARE"
    msg2="PRODUCT (\"SOFTWARE\") IS PROVIDED TO YOU \"AS IS\" WITHOUT WARRANTIES OR"
    msg4="CONDITIONS OF ANY KIND, WHETHER ORAL OR WRITTEN, EXPRESS OR IMPLIED."
    msg5="HP SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OR CONDITIONS OF"
    msg6="MERCHANTABILITY, SATISFACTORY QUALITY, NON-INFRINGEMENT AND FITNESS"
    msg7="FOR A PARTICULAR PURPOSE. Some countries, states and provinces do not"
    msg8="allow exclusions of implied warranties or conditions, so the above"
    msg9="exclusion may not apply to you. You may have other rights that vary"
    msg10="from country to country, state to state, or province to province."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 \n"

    msg1="LIMITATION OF LIABILITY. EXCEPT TO THE EXTENT PROHIBITED BY LOCAL LAW,"
    msg2="IN NO EVENT WILL HP OR ITS SUBSIDIARIES, AFFILIATES OR SUPPLIERS BE"
    msg3="LIABLE FOR DIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR OTHER DAMAGES"
    msg4="(INCLUDING LOST PROFIT, LOST DATA, OR DOWNTIME COSTS), ARISING OUT OF"
    msg5="THE USE, INABILITY TO USE, OR THE RESULTS OF USE OF THE SOFTWARE,"
    msg6="WHETHER BASED IN WARRANTY, CONTRACT, TORT OR OTHER LEGAL THEORY, AND"
    msg7="WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. Your use of"
    msg8="the Software is entirely at your own risk. Should the Software prove"
    msg9="defective, you assume the entire cost of all service, repair or"
    msg10="correction. Some countries, states and provinces do not allow the"
    msg11="exclusion or limitation of liability for incidental or consequential"
    msg12="damages, so the above limitation may not apply to you."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 $msg11 $msg12 \n"

    msg1="NOTE. EXCEPT TO THE EXTENT ALLOWED BY LOCAL LAW, THESE WARRANTY TERMS"
    msg2="DO NOT EXCLUDE, RESTRICT OR MODIFY, AND ARE IN ADDITION TO, THE"
    msg3="MANDATORY STATUTORY RIGHTS APPLICABLE TO THE LICENSE OF THE SOFTWARE"
    msg4="TO YOU."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 \n"

}

# Function:
#	fileVersionTest Version PathFilename
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 Version, The version of the file in this script
#	$2 PathFilename, path/filename of file to test
#
# Returns:
#	0 Script file older than installed file
#	1 Script file the same as installed file
#	2 Script file newier than install file
#
function fileVersionTest {

	new_ver=$(fixVersion $1)

	base=$(basename $2)
	ext=$(basename $2 | cut -f2 -d'.')
	case $ext in
	lpd)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	paf)
		# Version format: APX-1-001 or 100
		old_ver=$(grep 'paf-x-file-version' $2 | cut -f2 -d\= )
		;;
	pcf)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	pfo)
		# The version is not provided in all the files.
		# Version format: 1.0
		old_ver=$(grep 'FileVersion' $2 | cut -f2 -d\: )
		[[ -z $old_ver ]] && old_ver="0.0"
		;;
	[rp]pd)
		# Version format: "1.0"
		old_ver=$(grep '\*FileVersion' $2 | cut -f2 -d\: )
		;;
	*)
		# Lpd print filter?
		old_ver=$(what $2 | tr -s '@' '\n' | grep $base | grep 'Revision:' | cut -f4 -d\$ | cut -f2 -d: )
		;;
	esac

	old_ver=$(fixVersion $old_ver)

	# Are the versions the same?
	if [[ $new_ver = $old_ver ]] 
	then	# Yes
		return 1
	fi

	if [[ $new_ver > $old_ver ]]
	then
		# New file more current
		return 2
	else
		# System file more current
		return 0
	fi
}

# Function:
#	checkSumTest PathFilename CheckSum1 CheckSum2
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 PathFilename, path/filename
#	$2 CheckSum1,  First checksum value generated from the 'sum' command.
#	$3 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Checksum matched
#	1 Checksum error
#
function checkSumTest {

	sum1=`sum $1 | tr -s "  " " " | cut -f 1 -d ' '`
	sum2=`sum $1 | tr -s "  " " " | cut -f 2 -d ' '`

	if [[ $sum1 -ne $2 ]] || [[ $sum2 -ne $3 ]]
	then
		return 1
	else
		return 0
	fi
}

# Function:
#	installTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test to see if the directory exists and the file
#	uuencoded file is newier than the system file.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
function installTest {
	mkdir=0

	# Can't install the file if the directory doesn't exist.

	file_name=`basename $2`
	directory=`dirname $2`

	if [[ ! -d $directory ]]
	then
		if [[ $mkdir = 0 ]]
		then
			msg1="Error: File $file_name not installed because"
			msg2="directory $directory doesn't exist."
			wrapMsg "$msg1 $msg2"
			return 1
		else
			mkdir $directory
			chmod 755 $directory
			chown root:system $directory
		fi
	fi

	# If the file does not exist, it's ok to install.
	if [[ ! -e $2 ]]
	then
		return 0
	fi

	fileVersionTest $1 $2
	status=$?

	if [[ $status = 1 ]]
	then
		checkSumTest $2 $3 $4
		if [[ $? = 0 ]]
		then
			# Files are the same, don't install
			wrapMsg "The $file_name system file is current and will not be replaced.\n"
			return 1
		else
			# Versions are the same, but the files are different!
			print "Warning: File versions match but the files are different!">&2
			askUser "Replace $file_name"
			return $?
		fi
	fi

	if [[ $status = 0 ]]
	then
		wrapMsg "The $file_name system file is newier and will not be replaced.\n"
		return 1
 	fi

	return 0
}

# Function:
#	mimimumVersionTest version
#
# Description:
#	Test to see if the minimum application or operating version 
#	requirement is met.
#
# Arguments:
#	$1 Version,    Minimum install version requirement
#
# Returns:
#	0 test passed
#	1 test failed
#
function mimimumVersionTest {

	if [[ $KIT_TYPE = $KIT_APS ]]
	then
		# At this time there isn't a minimum APS requirement.
		return 0 
	fi

	# The only other kit type is LPD, so check the OS version.

	# Note: The version field moves 1 position between Digital UNIX
	#       and Compaq Tru64 UNIX, but is always before (Rev.
	temp=` strings /vmunix | grep '(Rev.' | grep UNIX | cut -f1 -d '(' `

	# The version is the last value
	for x in $temp
	{
	  osver=$x
	}

	# A field test version of the OS might not start with a V. At some
	# point we might need to note the difference, but for now we don't.
	# Modify the version string by replacing the first character with a V.

	temp=$osver
	osver="V$( echo "$osver" | cut -c2- )"

	if [[ $osver < $1 ]]
	then
		return 1
	fi

	return 0
}

# Function:
#	installLpdTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	If the file does not currently exist and the minimal install
#	requirements are met, a success status is returned.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Exits:
#	Exit if the minimum OS requirement is not met.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#
function installLpdTest {

	file_name=`basename $2`
	file_ext=`print "$file_name" | cut -f2 -d'.'`

	# Perform the OS test after this test. No reason to complain
	# about the os version if the file isn't going to be installed.
	if [[ $file_ext = "lpd" ]]
	then
		# If this is a .lpd file and the base directory doesn't exist
		# return.
		if [[ ! -d `dirname $2` ]]
		then
			msg1="File $file_name is not required for this version of Tru64 UNIX.\n"
			wrapMsg "$msg1"
			return 1
		fi
	fi

	installTest $1 $2 $3 $4
	return $?
}


# Function:
#	installApsTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test the minimal install requirements for an APS file. 
#
# Arguments:
#	$1 File version, File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#

function installApsTest {

	installTest $1 $2 $3 $4
	return $?
}

# Function:
#	fixVersion Version
#
# Description:
#	Remove unwanted characters.
#	Aps two version formats are converted to a common format.
#
# Arguments:
#	$1 Version, Version string
#
# Returns:
#	The updated version string.
#
function fixVersion {

	# Remove quotes, tabs, and spaces
	ver=$(echo $1 | tr -d "\"\t ")

	# Set null strings to version 0
	if [[ -z $ver ]]
	then
		ver=0
	fi

	# If the version starts with 'a', convert
	# a???-x-xxx to xxxx
	case $ver in
	[Aa]*)	;;
	[0123456789]*)
		# Return the version
		print "$ver"
		return
		;;
	*)	# Don't know what we found so return a version of 0.
		print "0.0"
		;;
	esac

	# To compare version 100 to apx-?-??? convert
	# apx-1-001 to 1001
	# apx-1-2   to 1002
	part1=$(echo "$ver" | cut -f2 -d\-)
	part2=$(echo "$ver" | cut -f3 -d\-)

	ver=$(printf "%s%.3d" $part1 $part2)

	# Return the version
	print "$ver"
	return
}

# Function:
#	preInstall FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Determine if this is an APS or LPD install and call the
#	appropriate function.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file
#	1 Don't install file
#
function preInstall {

	status=1

	if [[ $KIT_TYPE = $KIT_LPD ]] 
	then
		installLpdTest $1 $2 $3 $4
		status=$?
	fi

	if [[ $KIT_TYPE = $KIT_APS ]] 
	then
		installApsTest $1 $2 $3 $4
		status=$?
	fi

	# On install status, backup existing file
	# if it exists
	if [[ $status = 0 ]]
	then
		if [[ -e $2 ]]
		then
			# format = filename_yyyymmmdd_hh:mm:ss
			backup=$2_$(date +"b%d_%T")
			mv $2 $backup
			wrapMsg "Backup file $backup created."

			# Return the name of the backup file
			print "$backup"
		fi
	fi
	return $status
}

# Function:
#	postInstall BackupFile Owner Group Protection FileName CheckSum1 CheckSum2
#
# Description:
#	After the file has been installed verify the file checksum. If
#	the checksum is ok, set the file owner and protection.
#
#	Notify the user of a checksum error and prompt to remove the file.
#
# Arguments:
#	$1 BackupFile, Name of the backup file
#	$2 Owner,      File owner for chown command
#	$3 Group,      Group owner for chgrp command
#	$4 Protection, File protections number, eg 644, for chmod command
#	$5 FileName,   Installed file path/filename
#	$6 CheckSum1,  First checksum value generated from the 'sum' command.
#	$7 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	None
#
function postInstall {

	chown $2:$3 $5
	chmod $4 $5

	checkSumTest $5 $6 $7
	if [[ $? != 0 ]]
	then
		wrapMsg "Install checksum error on file $5!"

		if [[ ! -z $1 ]]
		then
			askUser "Restore the backup file"
		else
			askUser "Delete the file $5"
		fi

		if [[ $? = 0 ]]
		then 
			rm $5
			if [[ ! -z $1 ]]
			then
				mv $1 $5
				wrapMsg "Backup file restored.\n"
			else
				wrapMsg "File $5 deleted.\n"
			fi
		fi
	else
		wrapMsg "File $5 installed.\n"
		FileInstalled=1
	fi
	return
}

# Function:
#	doHelp
#
# Description:
#	Display the install script options.
#
# Arguments:
#	None
#
# Returns:
#	None
#
function doHelp {
	print "Synopsis: $(basename $0) -option" >&2
	print "" >&2
	print "Options:  -i Install files" >&2
	print "          -p Printer configuration instructions" >&2
	print "" >&2
	return
}

#
# Program
#

typeset -xi FileInstalled=0

# Identify the program

if [[ $KIT_TYPE = $KIT_LPD ]]
then
	print "LPD \c"

elif [[ $KIT_TYPE = $KIT_APS ]]
then
	print "Advanced Printing Software \c"
fi

print "installation kit for: $KIT_PRINTER\n"


# When no arguments are provided, display the help text and exit.
if [[  $# = 0 ]]
then
	doHelp
	exit 0
fi

while getopts :hip opt
do
        case $opt in
	h)	doHelp
		exit 0
		;;
	i)	# Install, fall out of case statement
		;;
	p)	# Print post-install setup instructions
		setupInstructions
		exit 0
		;;
	\?)	doHelp
		exit 0
                ;;
        esac
done

UserName=`whoami`

if [[ $UserName != "root" ]]
then
	print "You must be root to run this program."
	exit 1
fi

mimimumVersionTest $KIT_MINVER
if [[ $? != 0 ]]
then
	msg1="This installation requires a minimum"
	msg2="operating system version of $1."
	wrapMsg "$msg1 $msg2"
	exit 1
fi

subset_name=UNKNOWN
if [[ $KIT_TYPE = $KIT_LPD ]]
then
	subset_name=OSFPRINT
elif [[ $KIT_TYPE = $KIT_APS ]]
then
	subset_name=APXBASE
else
	print "Error: Unknown kit type."
	exit 1
fi

if [ ! -e /usr/.smdb./$subset_name*.lk ]
then
	print "The update requires the $subset_name subset to be installed."
	exit 1
fi

print "This kit contains the following files:\n"

echo "$KIT_FILES" | fold -s
print ""

PRESS_ENTER='Press ENTER to continue'

printf "$PRESS_ENTER"
read temp

PrintLicenseAgreement 2>&1 | pg -e -p "$PRESS_ENTER" >&2

askUser "Do you accept the terms in the license agreement"
if [[ $? != 0 ]]
then
	# User did not accept license agreement.
	print "No files were installed."
	exit 1
fi
print "\n\n"

#--- uuencoded files ---
backup_file=$(preInstall "APX-1-001" /usr/pd/share/cap/Digital_LN40_PS.paf 10704 3)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/pd/share/cap/Digital_LN40_PS.paf
M(R!0<FEN=&5R($%T=')I8G5T92!&:6QE(&9O<B!$:6=I=&%L($QA<V5R(%!R
M:6YT97(@3$XT,`HC(%)E=BX@,C8M3V-T+3(P,#`*(PHC($-O<'ER:6=H="`R
M,#`P($-O;7!A<2!#;VUP=71E<B!#;W)P;W)A=&EO;BX@($%L;"!R:6=H=',@
M<F5S97)V960N"B,*(R!0;W-T4V-R:7!T(&ES(&$@=')A9&5M87)K(&]F($%D
M;V)E(%-Y<W1E;7,@26YC;W)P;W)A=&5D+@H*<&%F+7@M9FEL92UN86UE/2)$
M:6=I=&%L7TQ.-#!?4%,N<&%F(@IP868M>"UF:6QE+79E<G-I;VX](D%06"TQ
M+3`P,2(*"G!R:6YT97(M;6]D96P](D1I9VET86P@3&%S97(@4')I;G1E<B!,
M3C0P(%!3(@IM87AI;75M+7!R:6YT97(M<W!E960]-#`*"FYA=&EV92UD;V-U
M;65N="UF;W)M871S+7)E861Y/2)0;W-T4V-R:7!T(@ID;V-U;65N="UF;W)M
M871S+7-U<'!O<G1E9#TB4&]S=%-C<FEP="(@(G-I;7!L92UT97AT(@ID;V-U
M;65N="UF;W)M871S+7)E861Y/2)0;W-T4V-R:7!T(B`B<VEM<&QE+71E>'0B
M"@IP;&5X97,M<W5P<&]R=&5D/2)S:6UP;&5X(B`B9'5P;&5X(B`B='5M8FQE
M(@IS:61E<RUS=7!P;W)T960](C$B("(R(@IS:61E<RUR96%D>3TB,2(@(C(B
M"@II;G!U="UT<F%Y<RUS=7!P;W)T960](G1O<"(@(FUI9&1L92(@(F)O='1O
M;2(*:6YP=70M=')A>7,M<F5A9'D](G1O<"(@(FUI9&1L92(@(F)O='1O;2(*
M"F]U='!U="UB:6YS+7-U<'!O<G1E9#TB=&]P(@IO=71P=70M8FEN<RUR96%D
M>3TB=&]P(@H*(R!P<FEV871E('-U<&5R=FES;W(@871T<FEB=71E<PH*<&%F
M+6YA=&EV92UD;V-U;65N="UF;W)M870M,3TB4&]S=%-C<FEP="(*<&%F+61E
M9F%U;'0M9&]C=6UE;G0M9F]R;6%T/2)0;W-T4V-R:7!T(@IP868M:F]B+7-E
M<&%R871O<BUF;W)M870](E!O<W138W)I<'0B"@HC(&-O;FYE8W1I;VXM<F5L
M871E9"!A='1R:6)U=&5S"@IP868M8V]N;F5C=&EO;BUL979E;"US97)I86P]
M-`IP868M8V]N;F5C=&EO;BUL979E;"UP87)A;&QE;#TR"G!A9BUC;VYN96-T
M:6]N+6QE=F5L+6EP+7-O8VME=#TT"G!R:6YT97(M=&-P:7`M<&]R="UN=6UB
M97(]-C@V.0H*(R!);G!U="!T<F%Y('-E;&5C=&EO;@HC"B,@1%!!($UA<'!E
M9"!N86UE("`@3$XT,"!T<F%Y(&YA;64*(R`M+2TM+2TM+2TM+2TM+2`@("`M
M+2TM+2TM+2TM+2TM+2T*(R!T;W`@("`@("`@("`@("`@("!5<'!E<@HC(&UI
M9&1L92`@("`@("`@("`@($UI9&1L90HC(&)O='1O;2`@("`@("`@("`@($QO
M=V5R"B,@<VED92`@("`@("`@("`@("`@3W!T:6]N86P@*&]P=&EO;F%L*2`*
M"G!A9BUT;W`M:6YP=70M8V]M;6%N9"TQ/2(@;6%R:R![("@\/"D@8W9X(&5X
M96,@+TEN<'5T071T<FEB=71E<R`H/#PI(&-V>"!E>&5C("]0<FEO<FET>2!;
M,5T@*#X^*2!C=G@@97AE8R`H/CXI(&-V>"!E>&5C('-E='!A9V5D979I8V4@
M?2!S=&]P<&5D(&-L96%R=&]M87)K("(*"G!A9BUM:61D;&4M:6YP=70M8V]M
M;6%N9"TQ/2(@;6%R:R![("@\/"D@8W9X(&5X96,@+TEN<'5T071T<FEB=71E
M<R`H/#PI(&-V>"!E>&5C("]0<FEO<FET>2!;,ET@*#X^*2!C=G@@97AE8R`H
M/CXI(&-V>"!E>&5C('-E='!A9V5D979I8V4@?2!S=&]P<&5D(&-L96%R=&]M
M87)K("(*"G!A9BUB;W1T;VTM:6YP=70M8V]M;6%N9"TQ/2(@;6%R:R![("@\
M/"D@8W9X(&5X96,@+TEN<'5T071T<FEB=71E<R`H/#PI(&-V>"!E>&5C("]0
M<FEO<FET>2!;,UT@*#X^*2!C=G@@97AE8R`H/CXI(&-V>"!E>&5C('-E='!A
M9V5D979I8V4@?2!S=&]P<&5D(&-L96%R=&]M87)K("(*"G!A9BUS:61E+6EN
M<'5T+6-O;6UA;F0M,3TB(&UA<FL@>R`H/#PI(&-V>"!E>&5C("]);G!U=$%T
M=')I8G5T97,@*#P\*2!C=G@@97AE8R`O4')I;W)I='D@6S5=("@^/BD@8W9X
M(&5X96,@*#X^*2!C=G@@97AE8R!S971P86=E9&5V:6-E('T@<W1O<'!E9"!C
M;&5A<G1O;6%R:R`B"@HC($]U='!U="!B:6X@<V5L96-T:6]N"B,*(R!$4$$@
M36%P<&5D(&YA;64@("!,3C0P(&)I;B!N86UE"B,@+2TM+2TM+2TM+2TM+2T@
M("`@+2TM+2TM+2TM+2TM+2TM"B,@=&]P("`@("`@("`@("`@("`@57!P97(*
M(R!F86-E+75P("`@("`@("`@("!&86-E57`O1F%C92UU<"!3=&%C:PHC(&9A
M8V4M9&]W;B`@("`@("`@($9A8V5$;W=N+T9A8V4M9&]W;B!3=&%C:PH@"G!A
M9BUT;W`M;W5T<'5T+6-O;6UA;F0M,3TB(&UA<FL@>R`H/#PI(&-V>"!E>&5C
M("]/=71P=71!='1R:6)U=&5S("@\/"D@8W9X(&5X96,@+U!R:6]R:71Y(%LQ
M72`H/CXI(&-V>"!E>&5C("@^/BD@8W9X(&5X96,@<V5T<&%G961E=FEC92!]
M('-T;W!P960@8VQE87)T;VUA<FL@(@H*<&%F+69A8V4M=7`M;W5T<'5T+6-O
M;6UA;F0M,3TB(&UA<FL@>R`H/#PI(&-V>"!E>&5C("]/=71P=71!='1R:6)U
M=&5S("@\/"D@8W9X(&5X96,@+U!R:6]R:71Y(%LR72`H/CXI(&-V>"!E>&5C
M("@^/BD@8W9X(&5X96,@<V5T<&%G961E=FEC92!]('-T;W!P960@8VQE87)T
M;VUA<FL@(@H*<&%F+69A8V4M9&]W;BUO=71P=70M8V]M;6%N9"TQ/2(@;6%R
M:R![("@\/"D@8W9X(&5X96,@+T]U='!U=$%T=')I8G5T97,@*#P\*2!C=G@@
M97AE8R`O4')I;W)I='D@6S-=("@^/BD@8W9X(&5X96,@*#X^*2!C=G@@97AE
M8R!S971P86=E9&5V:6-E('T@<W1O<'!E9"!C;&5A<G1O;6%R:R`B"@HC(%-I
M9&5S('-E;&5C=&EO;B`H9'5P;&5X97(@:7,@<W1A;F1A<F0I"B`*<&%F+7-E
M="US:6UP;&5X+6-O;6UA;F0M,3TB("@\/"D@8W9X(&5X96,@+T1U<&QE>"!F
M86QS92`O5'5M8FQE(&9A;'-E("@^/BD@8W9X(&5X96,@<V5T<&%G961E=FEC
M92`B"G!A9BUS970M9'5P;&5X+6-O;6UA;F0M,3TB("@\/"D@8W9X(&5X96,@
M+T1U<&QE>"!T<G5E("]4=6UB;&4@9F%L<V4@*#X^*2!C=G@@97AE8R!S971P
M86=E9&5V:6-E("(*<&%F+7-E="UT=6UB;&4M8V]M;6%N9"TQ/2(@*#P\*2!C
M=G@@97AE8R`O1'5P;&5X('1R=64@+U1U;6)L92!T<G5E("@^/BD@8W9X(&5X
;96,@<V5T<&%G961E=FEC92`B"@HC($5N9"X*
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/pd/share/cap/Digital_LN40_PS.paf 10704 3
fi

exit 0
